@@ -57,9 +57,10 @@
 #'
 #'   All other arguments are ignored with a warning.
 #' @param tolerance If non-`NULL`, used as threshold for ignoring small
-#'   floating point difference when comparing numeric vectors. Setting to
-#'   any non-`NULL` value will cause integer and double vectors to be compared
-#'   based on their values, rather than their types.
+#'   floating point difference when comparing numeric vectors. Using any
+#'   non-`NULL` value will cause integer and double vectors to be compared
+#'   based on their values, not their types, and will ignore the difference
+#'   between `NaN` and `NA_real_`.
 #'
 #'   It uses the same algorithm as [all.equal()], i.e., first we generate
 #'   `x_diff` and `y_diff` by subsetting `x` and `y` to look only locations
@@ -93,6 +94,9 @@
 #' @param list_as_map Compare lists as if they are mappings between names and
 #'   values. Concretely, this drops `NULLs` in both objects and sorts named
 #'   components.
+#' @param quote_strings Should strings be surrounded by quotes? If `FALSE`,
+#'   only side-by-side and line-by-line comparisons will be used, and there's
+#'   no way to distinguish between `NA` and `"NA"`.
 #' @returns A character vector with class "waldo_compare". If there are no
 #'   differences it will have length 0; otherwise each element contains the
 #'   description of a single difference.
@@ -129,7 +133,8 @@ compare <- function(x, y, ...,
                     ignore_encoding = TRUE,
                     ignore_function_env = FALSE,
                     ignore_formula_env = FALSE,
-                    list_as_map = FALSE
+                    list_as_map = FALSE,
+                    quote_strings = TRUE
                     ) {
 
   opts <- compare_opts(
@@ -141,7 +146,8 @@ compare <- function(x, y, ...,
     ignore_encoding = ignore_encoding,
     ignore_formula_env = ignore_formula_env,
     ignore_function_env = ignore_function_env,
-    list_as_map = list_as_map
+    list_as_map = list_as_map,
+    quote_strings = quote_strings
   )
   # Record options overridden by user
   opts$user_specified <- intersect(names(opts), names(match.call()))
@@ -370,7 +376,8 @@ compare_terminate <- function(x, y, paths,
     return(character())
   }
 
-  if (isTRUE(ignore_attr) && (typeof(x) == typeof(y))) {
+  ignore_class <- isTRUE(ignore_attr) || "class" %in% ignore_attr
+  if (ignore_class && (typeof(x) == typeof(y))) {
     return(character())
   }
 
